summaryrefslogtreecommitdiff
path: root/chromium/third_party/blink/tools/run_blink_httpd.py
diff options
context:
space:
mode:
Diffstat (limited to 'chromium/third_party/blink/tools/run_blink_httpd.py')
-rwxr-xr-xchromium/third_party/blink/tools/run_blink_httpd.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/chromium/third_party/blink/tools/run_blink_httpd.py b/chromium/third_party/blink/tools/run_blink_httpd.py
index 6594caab386..c27a4ffdf7f 100755
--- a/chromium/third_party/blink/tools/run_blink_httpd.py
+++ b/chromium/third_party/blink/tools/run_blink_httpd.py
@@ -27,18 +27,18 @@
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
"""Runs an Apache HTTP server to manually run layout tests locally.
After running this script, you can locally navigate to URLs where
-the path is relative to LayoutTests/http/tests/. For example, to run
-LayoutTests/http/tests/cachestorage/window-cache-add.html, navigate to:
+the path is relative to web_tests/http/tests/. For example, to run
+web_tests/http/tests/cachestorage/window-cache-add.html, navigate to:
http://127.0.0.1:8000/cachestorage/window/cache-add.html
When using HTTPS, for example:
https://127.0.0.1:8443/https/verify-ssl-enabled.php
you will may a certificate warning, which you need to bypass.
-After starting the server, you can also run individual layout tests
+After starting the server, you can also run individual web tests
via content_shell, e.g.
$ out/Release/content_shell --run-web-tests \
http://127.0.0.1:8000/security/cross-frame-access-get.html
@@ -27,18 +27,18 @@
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-"""Runs an Apache HTTP server to manually run layout tests locally.
+"""Runs an Apache HTTP server to manually run web tests locally.
After running this script, you can locally navigate to URLs where